@@ -4,7 +4,7 @@ use strict;
 use vars qw($VERSION);
 use Carp;
 
-$VERSION = '2.07';
+$VERSION = '2.09';
 
 
 # LOAD FILTERING MODULE...
@@ -52,7 +52,6 @@ sub filter
 	return $status if $status<0;
     	$_ = filter_blocks($_,$offset);
 	$_ = "# line $offset\n" . $_ if $offset; undef $offset;
-	# print STDERR $_;
 	return $status;
 }
 
@@ -121,7 +120,6 @@ sub filter_blocks
 		{
 			my $keyword = $3;
 			my $arg = $4;
-			print  STDERR "[$arg]\n";
 			$text .= $1.$2.'S_W_I_T_C_H: while (1) ';
 			unless ($arg) {
 				@pos = Text::Balanced::_match_codeblock(\$source,qr/\s*/,qr/\(/,qr/\)/,qr/[[{(<]/,qr/[]})>]/,undef) 
@@ -492,8 +490,8 @@ Switch - A switch statement for Perl
 
 =head1 VERSION
 
-This document describes version 2.07 of Switch,
-released May 15, 2002.
+This document describes version 2.09 of Switch,
+released June 12, 2002.
 
 =head1 SYNOPSIS
 
